==> infima_client-0.190.0-py3-none-any.whl: infima_client/pool.py <==
from typing import Any, Dict, List, Optional, Union

import attr

import infima_client.api.pool_service.pool_service_coverage_check as pool_service_coverage_check
import infima_client.api.pool_service.pool_service_get_all_servicers as pool_service_get_all_servicers
import infima_client.api.pool_service.pool_service_get_characteristics as pool_service_get_characteristics
import infima_client.api.pool_service.pool_service_get_distributions as pool_service_get_distributions
import infima_client.api.pool_service.pool_service_get_geolocations as pool_service_get_geolocations
import infima_client.api.pool_service.pool_service_get_historical_prepayments as pool_service_get_historical_prepayments
import infima_client.api.pool_service.pool_service_get_pools as pool_service_get_pools
import infima_client.api.pool_service.pool_service_get_quartiles as pool_service_get_quartiles
import infima_client.api.pool_service.pool_service_get_servicers as pool_service_get_servicers
import infima_client.api.pool_service.pool_service_get_summaries as pool_service_get_summaries
from infima_client.models import *

from .client import Client
from .types import UNSET, Response, Unset
from .util import named_arguments_only


class pool:
    def __init__(self, client: Client):
        self.client = client
        self._detailed = poolDetailed(client)

    @named_arguments_only
    def coverage_check(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolCoverageCheck,
            PoolCoverageCheckUnauthorized,
            PoolCoverageCheckNotFound,
            PoolCoverageCheckError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_coverage_check.sync(
            client=self.client, json_body=GetPoolCoverageCheckRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_all_servicers(
        self,
    ) -> Optional[
        Union[
            PoolService_GetAllServicersResponse_200,
            PoolService_GetAllServicersResponse_401,
            PoolService_GetAllServicersResponse_404,
            PoolService_GetAllServicersResponse_500,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_all_servicers.sync(client=self.client)

    @named_arguments_only
    def get_characteristics(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        date: Union[PoolService_GetCharacteristicsJsonBodyDate, Unset] = UNSET,
    ) -> Optional[
        Union[
            PoolCharacteristics,
            PoolCharacteristicsUnauthorized,
            PoolCharacteristicsNotFound,
            PoolCharacteristicsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_characteristics.sync(
            client=self.client,
            json_body=GetPoolCharasteristicsRequest(cusips=cusips, date=date),
        )

    @named_arguments_only
    def get_distributions(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolDistributions,
            PoolDistributionsUnauthorized,
            PoolDistributionsNotFound,
            PoolDistributionsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_distributions.sync(
            client=self.client, json_body=GetDistributionRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_geolocations(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolGeoLocations,
            PoolGeoLocationsUnauthorized,
            PoolGeoLocationsNotFound,
            PoolGeoLocationsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_geolocations.sync(
            client=self.client, json_body=GetGeoRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_historical_prepayments(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        convention: Union[
            Unset, PoolService_GetHistoricalPrepaymentsJsonBodyConvention
        ] = PoolService_GetHistoricalPrepaymentsJsonBodyConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
        period: Union[
            PoolService_GetHistoricalPrepaymentsJsonBodyPeriod, Unset
        ] = UNSET,
    ) -> Optional[
        Union[
            PoolHistoricalPrepayments,
            PoolHistoricalPrepaymentsUnauthorized,
            PoolHistoricalPrepaymentsNotFound,
            PoolHistoricalPrepaymentsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_historical_prepayments.sync(
            client=self.client,
            json_body=GetHistoricalPrepaymentsRequest(
                convention=convention,
                cusips=cusips,
                num_months=num_months,
                period=period,
            ),
        )

    @named_arguments_only
    def get_pools(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[Union[Pool, PoolUnauthorized, PoolNotFound, PoolError]]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_pools.sync(
            client=self.client, json_body=GetPoolRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_quartiles(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolQuartiles,
            PoolQuartilesUnauthorized,
            PoolQuartilesNotFound,
            PoolQuartilesError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_quartiles.sync(
            client=self.client, json_body=GetQuartilesRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_servicers(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolServicers,
            PoolServicersUnauthorized,
            PoolServicersNotFound,
            PoolServicersError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_servicers.sync(
            client=self.client, json_body=GetServicersRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_summaries(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolSummaries,
            PoolSummariesUnauthorized,
            PoolSummariesNotFound,
            PoolSummariesError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_summaries.sync(
            client=self.client, json_body=GetSummariesRequest(cusips=cusips)
        )


class poolDetailed:
    def __init__(self, client: Client):
        self.client = client

    @named_arguments_only
    def coverage_check(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolCoverageCheck,
            PoolCoverageCheckUnauthorized,
            PoolCoverageCheckNotFound,
            PoolCoverageCheckError,
        ]
    ]:

        return pool_service_coverage_check.sync_detailed(
            client=self.client, json_body=GetPoolCoverageCheckRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_all_servicers(
        self,
    ) -> Response[
        Union[
            PoolService_GetAllServicersResponse_200,
            PoolService_GetAllServicersResponse_401,
            PoolService_GetAllServicersResponse_404,
            PoolService_GetAllServicersResponse_500,
        ]
    ]:

        return pool_service_get_all_servicers.sync_detailed(client=self.client)

    @named_arguments_only
    def get_characteristics(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        date: Union[PoolService_GetCharacteristicsJsonBodyDate, Unset] = UNSET,
    ) -> Response[
        Union[
            PoolCharacteristics,
            PoolCharacteristicsUnauthorized,
            PoolCharacteristicsNotFound,
            PoolCharacteristicsError,
        ]
    ]:

        return pool_service_get_characteristics.sync_detailed(
            client=self.client,
            json_body=GetPoolCharasteristicsRequest(cusips=cusips, date=date),
        )

    @named_arguments_only
    def get_distributions(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolDistributions,
            PoolDistributionsUnauthorized,
            PoolDistributionsNotFound,
            PoolDistributionsError,
        ]
    ]:

        return pool_service_get_distributions.sync_detailed(
            client=self.client, json_body=GetDistributionRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_geolocations(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolGeoLocations,
            PoolGeoLocationsUnauthorized,
            PoolGeoLocationsNotFound,
            PoolGeoLocationsError,
        ]
    ]:

        return pool_service_get_geolocations.sync_detailed(
            client=self.client, json_body=GetGeoRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_historical_prepayments(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        convention: Union[
            Unset, PoolService_GetHistoricalPrepaymentsJsonBodyConvention
        ] = PoolService_GetHistoricalPrepaymentsJsonBodyConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
        period: Union[
            PoolService_GetHistoricalPrepaymentsJsonBodyPeriod, Unset
        ] = UNSET,
    ) -> Response[
        Union[
            PoolHistoricalPrepayments,
            PoolHistoricalPrepaymentsUnauthorized,
            PoolHistoricalPrepaymentsNotFound,
            PoolHistoricalPrepaymentsError,
        ]
    ]:

        return pool_service_get_historical_prepayments.sync_detailed(
            client=self.client,
            json_body=GetHistoricalPrepaymentsRequest(
                convention=convention,
                cusips=cusips,
                num_months=num_months,
                period=period,
            ),
        )

    @named_arguments_only
    def get_pools(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[Union[Pool, PoolUnauthorized, PoolNotFound, PoolError]]:

        return pool_service_get_pools.sync_detailed(
            client=self.client, json_body=GetPoolRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_quartiles(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolQuartiles,
            PoolQuartilesUnauthorized,
            PoolQuartilesNotFound,
            PoolQuartilesError,
        ]
    ]:

        return pool_service_get_quartiles.sync_detailed(
            client=self.client, json_body=GetQuartilesRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_servicers(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolServicers,
            PoolServicersUnauthorized,
            PoolServicersNotFound,
            PoolServicersError,
        ]
    ]:

        return pool_service_get_servicers.sync_detailed(
            client=self.client, json_body=GetServicersRequest(cusips=cusips)
        )

    @named_arguments_only
    def get_summaries(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolSummaries,
            PoolSummariesUnauthorized,
            PoolSummariesNotFound,
            PoolSummariesError,
        ]
    ]:

        return pool_service_get_summaries.sync_detailed(
            client=self.client, json_body=GetSummariesRequest(cusips=cusips)
        )

==> infima_client-0.259.0-py3-none-any.whl: infima_client/pool.py <==
from typing import Any, Dict, List, Optional, Union

import attr

import infima_client.api.pool_service.pool_service_coverage_check as pool_service_coverage_check
import infima_client.api.pool_service.pool_service_get_all_servicers as pool_service_get_all_servicers
import infima_client.api.pool_service.pool_service_get_characteristics as pool_service_get_characteristics
import infima_client.api.pool_service.pool_service_get_distributions as pool_service_get_distributions
import infima_client.api.pool_service.pool_service_get_geolocations as pool_service_get_geolocations
import infima_client.api.pool_service.pool_service_get_historical_prepayments as pool_service_get_historical_prepayments
import infima_client.api.pool_service.pool_service_get_pools as pool_service_get_pools
import infima_client.api.pool_service.pool_service_get_quartiles as pool_service_get_quartiles
import infima_client.api.pool_service.pool_service_get_servicers as pool_service_get_servicers
import infima_client.api.pool_service.pool_service_get_summaries as pool_service_get_summaries
from infima_client.models import *

from .client import Client
from .types import UNSET, Response, Unset
from .util import named_arguments_only


class pool:
    def __init__(self, client: Client):
        self.client = client
        self._detailed = poolDetailed(client)

    @named_arguments_only
    def coverage_check(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolCoverageCheck,
            PoolCoverageCheckUnauthorized,
            PoolCoverageCheckNotFound,
            PoolCoverageCheckError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_coverage_check.sync(
            client=self.client,
            json_body=PoolService_CoverageCheckJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_all_servicers(
        self,
    ) -> Optional[
        Union[
            PoolService_GetAllServicersResponse_200,
            PoolService_GetAllServicersResponse_401,
            PoolService_GetAllServicersResponse_404,
            PoolService_GetAllServicersResponse_500,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_all_servicers.sync(client=self.client)

    @named_arguments_only
    def get_characteristics(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        date: Union[PoolService_GetCharacteristicsJsonBodyDate, Unset] = UNSET,
    ) -> Optional[
        Union[
            PoolCharacteristics,
            PoolCharacteristicsUnauthorized,
            PoolCharacteristicsNotFound,
            PoolCharacteristicsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_characteristics.sync(
            client=self.client,
            json_body=PoolService_GetCharacteristicsJsonBody(cusips=cusips, date=date),
        )

    @named_arguments_only
    def get_distributions(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolDistributions,
            PoolDistributionsUnauthorized,
            PoolDistributionsNotFound,
            PoolDistributionsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_distributions.sync(
            client=self.client,
            json_body=PoolService_GetDistributionsJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_geolocations(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolGeoLocations,
            PoolGeoLocationsUnauthorized,
            PoolGeoLocationsNotFound,
            PoolGeoLocationsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_geolocations.sync(
            client=self.client,
            json_body=PoolService_GetGeolocationsJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_historical_prepayments(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        convention: Union[
            Unset, PoolService_GetHistoricalPrepaymentsJsonBodyConvention
        ] = PoolService_GetHistoricalPrepaymentsJsonBodyConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
        period: Union[
            PoolService_GetHistoricalPrepaymentsJsonBodyPeriod, Unset
        ] = UNSET,
    ) -> Optional[
        Union[
            PoolHistoricalPrepayments,
            PoolHistoricalPrepaymentsUnauthorized,
            PoolHistoricalPrepaymentsNotFound,
            PoolHistoricalPrepaymentsError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_historical_prepayments.sync(
            client=self.client,
            json_body=PoolService_GetHistoricalPrepaymentsJsonBody(
                convention=convention,
                cusips=cusips,
                num_months=num_months,
                period=period,
            ),
        )

    @named_arguments_only
    def get_pools(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[Union[Pool, PoolUnauthorized, PoolNotFound, PoolError]]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_pools.sync(
            client=self.client, json_body=PoolService_GetPoolsJsonBody(cusips=cusips)
        )

    @named_arguments_only
    def get_quartiles(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolQuartiles,
            PoolQuartilesUnauthorized,
            PoolQuartilesNotFound,
            PoolQuartilesError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_quartiles.sync(
            client=self.client,
            json_body=PoolService_GetQuartilesJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_servicers(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolServicers,
            PoolServicersUnauthorized,
            PoolServicersNotFound,
            PoolServicersError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_servicers.sync(
            client=self.client,
            json_body=PoolService_GetServicersJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_summaries(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Optional[
        Union[
            PoolSummaries,
            PoolSummariesUnauthorized,
            PoolSummariesNotFound,
            PoolSummariesError,
        ]
    ]:

        """


        Args:

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return pool_service_get_summaries.sync(
            client=self.client,
            json_body=PoolService_GetSummariesJsonBody(cusips=cusips),
        )


class poolDetailed:
    def __init__(self, client: Client):
        self.client = client

    @named_arguments_only
    def coverage_check(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolCoverageCheck,
            PoolCoverageCheckUnauthorized,
            PoolCoverageCheckNotFound,
            PoolCoverageCheckError,
        ]
    ]:

        return pool_service_coverage_check.sync_detailed(
            client=self.client,
            json_body=PoolService_CoverageCheckJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_all_servicers(
        self,
    ) -> Response[
        Union[
            PoolService_GetAllServicersResponse_200,
            PoolService_GetAllServicersResponse_401,
            PoolService_GetAllServicersResponse_404,
            PoolService_GetAllServicersResponse_500,
        ]
    ]:

        return pool_service_get_all_servicers.sync_detailed(client=self.client)

    @named_arguments_only
    def get_characteristics(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        date: Union[PoolService_GetCharacteristicsJsonBodyDate, Unset] = UNSET,
    ) -> Response[
        Union[
            PoolCharacteristics,
            PoolCharacteristicsUnauthorized,
            PoolCharacteristicsNotFound,
            PoolCharacteristicsError,
        ]
    ]:

        return pool_service_get_characteristics.sync_detailed(
            client=self.client,
            json_body=PoolService_GetCharacteristicsJsonBody(cusips=cusips, date=date),
        )

    @named_arguments_only
    def get_distributions(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolDistributions,
            PoolDistributionsUnauthorized,
            PoolDistributionsNotFound,
            PoolDistributionsError,
        ]
    ]:

        return pool_service_get_distributions.sync_detailed(
            client=self.client,
            json_body=PoolService_GetDistributionsJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_geolocations(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolGeoLocations,
            PoolGeoLocationsUnauthorized,
            PoolGeoLocationsNotFound,
            PoolGeoLocationsError,
        ]
    ]:

        return pool_service_get_geolocations.sync_detailed(
            client=self.client,
            json_body=PoolService_GetGeolocationsJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_historical_prepayments(
        self,
        cusips: Union[Unset, List[str]] = UNSET,
        convention: Union[
            Unset, PoolService_GetHistoricalPrepaymentsJsonBodyConvention
        ] = PoolService_GetHistoricalPrepaymentsJsonBodyConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
        period: Union[
            PoolService_GetHistoricalPrepaymentsJsonBodyPeriod, Unset
        ] = UNSET,
    ) -> Response[
        Union[
            PoolHistoricalPrepayments,
            PoolHistoricalPrepaymentsUnauthorized,
            PoolHistoricalPrepaymentsNotFound,
            PoolHistoricalPrepaymentsError,
        ]
    ]:

        return pool_service_get_historical_prepayments.sync_detailed(
            client=self.client,
            json_body=GetHistoricalPrepaymentsRequest(
                convention=convention,
                cusips=cusips,
                num_months=num_months,
                period=period,
            ),
        )

    @named_arguments_only
    def get_pools(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[Union[Pool, PoolUnauthorized, PoolNotFound, PoolError]]:

        return pool_service_get_pools.sync_detailed(
            client=self.client, json_body=PoolService_GetPoolsJsonBody(cusips=cusips)
        )

    @named_arguments_only
    def get_quartiles(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolQuartiles,
            PoolQuartilesUnauthorized,
            PoolQuartilesNotFound,
            PoolQuartilesError,
        ]
    ]:

        return pool_service_get_quartiles.sync_detailed(
            client=self.client,
            json_body=PoolService_GetQuartilesJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_servicers(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolServicers,
            PoolServicersUnauthorized,
            PoolServicersNotFound,
            PoolServicersError,
        ]
    ]:

        return pool_service_get_servicers.sync_detailed(
            client=self.client,
            json_body=PoolService_GetServicersJsonBody(cusips=cusips),
        )

    @named_arguments_only
    def get_summaries(
        self, cusips: Union[Unset, List[str]] = UNSET
    ) -> Response[
        Union[
            PoolSummaries,
            PoolSummariesUnauthorized,
            PoolSummariesNotFound,
            PoolSummariesError,
        ]
    ]:

        return pool_service_get_summaries.sync_detailed(
            client=self.client,
            json_body=PoolService_GetSummariesJsonBody(cusips=cusips),
        )
